@@ -10,7 +10,7 @@ from nonebot.adapters.onebot.v11 import (GROUP, PRIVATE_FRIEND, Bot,
                                          PrivateMessageEvent)
 from nonebot.exception import ActionFailed
 from nonebot.log import logger
-from nonebot.params import CommandArg, State
+from nonebot.params import CommandArg
 from nonebot.permission import SUPERUSER
 from nonebot.typing import T_State
 
@@ -36,8 +36,6 @@ from .resource.setu_message import setu_sendmessage
 # ⣿⣦⡀⣿⣿⣷⣶⣬⣍⣛⣛⣛⡛⠿⠿⠿⠛⠛⢛⣛⣉⣭⣤⣂⢜⠕⢑⣡⣴⣿
 
 
-
-
 # --------------- 初始化变量 ---------------
 # 实例化权限管理
 pm = PermissionManager()
@@ -79,7 +77,7 @@ setu = on_regex(
 
 # 响应器处理操作
 @setu.handle()
-async def _(bot: Bot, event: MessageEvent, state: T_State = State()):
+async def _(bot: Bot, event: MessageEvent, state: T_State):
     # 获取用户输入的参数
     args = list(state["_matched_groups"])
     r18flag = args[2]
@@ -118,6 +116,7 @@ async def _(bot: Bot, event: MessageEvent, state: T_State = State()):
     # 记录时间, 计算CD用
     pm.UpdateLastSend(sessionId)
     # data是数组套娃, 数组中的每个元素内容为: [图片, 信息, True/False, url]
+
     data = await get_setu(key, r18, num, quality)
 
     # 发送的消息列表
@@ -128,6 +127,7 @@ async def _(bot: Bot, event: MessageEvent, state: T_State = State()):
             message = f"{random.choice(setu_sendmessage)}{flagLog}" + \
                 Message(pic[1]) + MessageSegment.image(pic[0])
             message_list.append(message)
+            flagLog = ''
         # 状态为false的消息,图片没拿到
         else:
             message = pic[0] + pic[1]
@@ -180,7 +180,7 @@ async def _(bot: Bot, event: MessageEvent, state: T_State = State()):
 open_setu = on_command("setu_wl", permission=SUPERUSER, block=True, priority=10)
 # 分析是新增还是删除
 @open_setu.handle()
-async def cmdArg(cmd:Message = CommandArg(), state: T_State = State()):
+async def cmdArg(state: T_State,cmd:Message = CommandArg()):
     if   'add' in str(cmd):
         state['add_mode'] = True
     elif 'del' in str(cmd):
@@ -189,11 +189,11 @@ async def cmdArg(cmd:Message = CommandArg(), state: T_State = State()):
         await open_setu.finish(f'无效参数: {cmd}, 请输入 add 或 del 为参数')
 # 群聊部分自动获取sid
 @open_setu.handle()
-async def group(event:GroupMessageEvent, state: T_State = State()):
+async def group(event:GroupMessageEvent, state: T_State):
     state['sid'] = 'group_' + str(event.group_id)
 # 手动获取sid, 并调用对应的方法进行处理
 @open_setu.got('sid',prompt='请按照 “会话类型_会话id” 的格式输入目标对象, 例如:\ngroup_114514\nuser_1919810')
-async def _(state: T_State = State()):
+async def _(state: T_State):
     sid = str(state['sid'])
     if not verifySid(sid):
         await open_setu.reject(f"无效目标对象: {sid}")
@@ -203,7 +203,7 @@ async def _(state: T_State = State()):
 set_r18 = on_command("setu_r18", permission=SUPERUSER, block=True, priority=10)
 # 分析是开启还是关闭
 @set_r18.handle()
-async def cmdArg(cmd:Message = CommandArg(), state: T_State = State()):
+async def cmdArg(state: T_State,cmd:Message = CommandArg()):
     if 'on' in str(cmd):
         state['r18Mode'] = True
     elif 'off' in str(cmd):
@@ -212,11 +212,11 @@ async def cmdArg(cmd:Message = CommandArg(), state: T_State = State()):
         await set_r18.finish(f'无效参数: {cmd}, 请输入 on 或 off 为参数')
 # 群聊部分自动获取sid
 @set_r18.handle()
-async def group(event:GroupMessageEvent, state: T_State = State()):
+async def group(event:GroupMessageEvent, state: T_State):
     state['sid'] = 'group_' + str(event.group_id)
 # 手动获取sid, 并调用对应的方法进行处理
 @set_r18.got('sid',prompt='请按照 “会话类型_会话id” 的格式输入目标对象, 例如:\ngroup_114514\nuser_1919810')
-async def _(state: T_State = State()):
+async def _(state: T_State):
     sid = str(state['sid'])
     if not verifySid(sid):
         await set_r18.reject(f"无效目标对象: {sid}")
@@ -226,18 +226,18 @@ async def _(state: T_State = State()):
 set_cd = on_command("setu_cd", permission=SUPERUSER, block=True, priority=10)
 # 获取参数
 @set_cd.handle()
-async def cmdArg(cmd:Message = CommandArg(), state: T_State = State()):
+async def cmdArg(state: T_State,cmd:Message = CommandArg()):
     try:
         state['cdTime'] = int(str(cmd))
     except:
         await set_cd.finish(f'无效参数: {cmd}, 请输入 正整数 或 0 为参数')
 # 群聊部分自动获取sid
 @set_cd.handle()
-async def group(event:GroupMessageEvent, state: T_State = State()):
+async def group(event:GroupMessageEvent, state: T_State):
     state['sid'] = 'group_' + str(event.group_id)
 # 手动获取sid, 并调用对应的方法进行处理
 @set_cd.got('sid',prompt='请按照 “会话类型_会话id” 的格式输入目标对象, 例如:\ngroup_114514\nuser_1919810')
-async def _(state: T_State = State()):
+async def _(state: T_State):
     sid = str(state['sid'])
     if not verifySid(sid):
         await set_cd.reject(f"无效目标对象: {sid}")
@@ -247,18 +247,18 @@ async def _(state: T_State = State()):
 set_wd = on_command("setu_wd", permission=SUPERUSER, block=True, priority=10)
 # 获取参数
 @set_wd.handle()
-async def cmdArg(cmd:Message = CommandArg(), state: T_State = State()):
+async def cmdArg(state: T_State,cmd:Message = CommandArg()):
     try:
         state['withdrawTime'] = int(str(cmd))
     except:
         await set_wd.finish(f'无效参数: {cmd}, 请输入 正整数 或 0 为参数')
 # 群聊部分自动获取sid
 @set_wd.handle()
-async def group(event:GroupMessageEvent, state: T_State = State()):
+async def group(event:GroupMessageEvent, state: T_State):
     state['sid'] = 'group_' + str(event.group_id)
 # 手动获取sid, 并调用对应的方法进行处理
 @set_wd.got('sid',prompt='请按照 “会话类型_会话id” 的格式输入目标对象, 例如:\ngroup_114514\nuser_1919810')
-async def _(state: T_State = State()):
+async def _(state: T_State):
     sid = str(state['sid'])
     if not verifySid(sid):
         await set_wd.reject(f"无效目标对象: {sid}")
@@ -268,18 +268,18 @@ async def _(state: T_State = State()):
 set_maxnum = on_command("setu_mn", permission=SUPERUSER, block=True, priority=10)
 # 获取参数
 @set_maxnum.handle()
-async def cmdArg(cmd:Message = CommandArg(), state: T_State = State()):
+async def cmdArg(state: T_State,cmd:Message = CommandArg(), ):
     try:
         state['maxNum'] = int(str(cmd))
     except:
         await set_maxnum.finish(f'无效参数: {cmd}, 请输入 正整数 为参数')
 # 群聊部分自动获取sid
 @set_maxnum.handle()
-async def group(event:GroupMessageEvent, state: T_State = State()):
+async def group(event:GroupMessageEvent, state: T_State):
     state['sid'] = 'group_' + str(event.group_id)
 # 手动获取sid, 并调用对应的方法进行处理
 @set_maxnum.got('sid',prompt='请按照 “会话类型_会话id” 的格式输入目标对象, 例如:\ngroup_114514\nuser_1919810')
-async def _(state: T_State = State()):
+async def _(state: T_State):
     sid = str(state['sid'])
     if not verifySid(sid):
         await set_maxnum.reject(f"无效目标对象: {sid}")
@@ -289,7 +289,7 @@ async def _(state: T_State = State()):
 ban_setu = on_command("setu_ban", permission=SUPERUSER, block=True, priority=10)
 # 分析是新增还是删除
 @ban_setu.handle()
-async def cmdArg(cmd:Message = CommandArg(), state: T_State = State()):
+async def cmdArg(state: T_State,cmd:Message = CommandArg()):
     if   'add' in str(cmd):
         state['add_mode'] = True
     elif 'del' in str(cmd):
@@ -298,11 +298,11 @@ async def cmdArg(cmd:Message = CommandArg(), state: T_State = State()):
         await ban_setu.finish(f'无效参数: {cmd}, 请输入 add 或 del 为参数')
 # 群聊部分自动获取sid
 @ban_setu.handle()
-async def group(event:GroupMessageEvent, state: T_State = State()):
+async def group(event:GroupMessageEvent, state: T_State):
     state['sid'] = 'group_' + str(event.group_id)
 # 手动获取sid, 并调用对应的方法进行处理
 @ban_setu.got('sid',prompt='请按照 “会话类型_会话id” 的格式输入目标对象, 例如:\ngroup_114514\nuser_1919810')
-async def _(state: T_State = State()):
+async def _(state: T_State):
     sid = str(state['sid'])
     if not verifySid(sid):
         await ban_setu.reject(f"无效目标对象: {sid}")
