@@ -21,7 +21,7 @@ except:
 try:
     setu_proxy = nonebot.get_driver().config.setu_proxy
 except:
-    setu_proxy = 'px2.rainchan.win'
+    setu_proxy = 'i.pixiv.re'
 
 
 
@@ -96,8 +96,12 @@ async def pic(setu, quality, client):
             except Exception as e:
                 logger.error(f'图片存储失败: {e}')
         image = Image.open(BytesIO(content))
-    pic = await change_pixel(image, quality)
-    return [pic, data, True, setu_url]
+    try:
+        pic = await change_pixel(image, quality)
+        return [pic, data, True, setu_url]
+    except:
+        return [error, f"图片处理失败", False, setu_url]
+        
 
 # 图像镜像左右翻转
 async def change_pixel(image:Image, quality):
